.github
.gitignore
CHANGELOG.TXT
CODEOWNERS
CODE_OF_CONDUCT.md
CONTRIBUTING.md
INSTALL.TXT
LATEX_README.TXT
LICENSE.TXT
README.md
RELEASE
SECURITY.md
TRANSLATORS.TXT
UPGRADE.TXT
VERSION
admin
cache
favicon.ico
fonts
images
index.php
install
public
shared